from typing import List
from enum import Enum
from pyVmomi import vim, vmodl
from datetime import datetime
from pyVmomi.VmomiSupport import ManagedObject, NoneType, PropertyPath, binary, byte
from . import profileEngine as profileEngine


class HostProfile(vim.profile.Profile):
    @property
    def validationState(self) -> str: ...
    @property
    def validationStateUpdateTime(self) -> datetime: ...
    @property
    def validationFailureInfo(self) -> HostProfile.ValidationFailureInfo: ...
    @property
    def complianceCheckTime(self) -> datetime: ...
    @property
    def referenceHost(self) -> vim.HostSystem: ...
    def ResetValidationState(self) -> NoneType: ...
    def UpdateReferenceHost(self, host: vim.HostSystem) -> NoneType: ...
    def Update(self, config: HostProfile.ConfigSpec) -> NoneType: ...
    def Execute(self, host: vim.HostSystem, deferredParam: List[vim.profile.DeferredPolicyOptionParameter]) -> ExecuteResult: ...


    class CompleteConfigSpec(HostProfile.ConfigSpec):
        @property
        def applyProfile(self) -> HostApplyProfile: ...
        @applyProfile.setter
        def applyProfile(self, value: HostApplyProfile):
            self._applyProfile = value
        @property
        def customComplyProfile(self) -> vim.profile.ComplianceProfile: ...
        @customComplyProfile.setter
        def customComplyProfile(self, value: vim.profile.ComplianceProfile):
            self._customComplyProfile = value
        @property
        def disabledExpressionListChanged(self) -> bool: ...
        @disabledExpressionListChanged.setter
        def disabledExpressionListChanged(self, value: bool):
            self._disabledExpressionListChanged = value
        @property
        def disabledExpressionList(self) -> List[str]: ...
        @disabledExpressionList.setter
        def disabledExpressionList(self, value: List[str]):
            self._disabledExpressionList = value
        @property
        def validatorHost(self) -> vim.HostSystem: ...
        @validatorHost.setter
        def validatorHost(self, value: vim.HostSystem):
            self._validatorHost = value
        @property
        def validating(self) -> bool: ...
        @validating.setter
        def validating(self, value: bool):
            self._validating = value
        @property
        def hostConfig(self) -> HostProfile.ConfigInfo: ...
        @hostConfig.setter
        def hostConfig(self, value: HostProfile.ConfigInfo):
            self._hostConfig = value


    class ConfigInfo(vim.profile.Profile.ConfigInfo):
        @property
        def applyProfile(self) -> HostApplyProfile: ...
        @applyProfile.setter
        def applyProfile(self, value: HostApplyProfile):
            self._applyProfile = value
        @property
        def defaultComplyProfile(self) -> vim.profile.ComplianceProfile: ...
        @defaultComplyProfile.setter
        def defaultComplyProfile(self, value: vim.profile.ComplianceProfile):
            self._defaultComplyProfile = value
        @property
        def defaultComplyLocator(self) -> List[vim.profile.ComplianceLocator]: ...
        @defaultComplyLocator.setter
        def defaultComplyLocator(self, value: List[vim.profile.ComplianceLocator]):
            self._defaultComplyLocator = value
        @property
        def customComplyProfile(self) -> vim.profile.ComplianceProfile: ...
        @customComplyProfile.setter
        def customComplyProfile(self, value: vim.profile.ComplianceProfile):
            self._customComplyProfile = value
        @property
        def disabledExpressionList(self) -> List[str]: ...
        @disabledExpressionList.setter
        def disabledExpressionList(self, value: List[str]):
            self._disabledExpressionList = value
        @property
        def description(self) -> vim.profile.Profile.Description: ...
        @description.setter
        def description(self, value: vim.profile.Profile.Description):
            self._description = value


    class ConfigSpec(vim.profile.Profile.CreateSpec): ...


    class HostBasedConfigSpec(HostProfile.ConfigSpec):
        @property
        def host(self) -> vim.HostSystem: ...
        @host.setter
        def host(self, value: vim.HostSystem):
            self._host = value
        @property
        def useHostProfileEngine(self) -> bool: ...
        @useHostProfileEngine.setter
        def useHostProfileEngine(self, value: bool):
            self._useHostProfileEngine = value


    class SerializedHostProfileSpec(vim.profile.Profile.SerializedCreateSpec):
        @property
        def validatorHost(self) -> vim.HostSystem: ...
        @validatorHost.setter
        def validatorHost(self, value: vim.HostSystem):
            self._validatorHost = value
        @property
        def validating(self) -> bool: ...
        @validating.setter
        def validating(self, value: bool):
            self._validating = value


    class ValidationFailureInfo(vmodl.DynamicData):
        @property
        def name(self) -> str: ...
        @name.setter
        def name(self, value: str):
            self._name = value
        @property
        def annotation(self) -> str: ...
        @annotation.setter
        def annotation(self, value: str):
            self._annotation = value
        @property
        def updateType(self) -> str: ...
        @updateType.setter
        def updateType(self, value: str):
            self._updateType = value
        @property
        def host(self) -> vim.HostSystem: ...
        @host.setter
        def host(self, value: vim.HostSystem):
            self._host = value
        @property
        def applyProfile(self) -> HostApplyProfile: ...
        @applyProfile.setter
        def applyProfile(self, value: HostApplyProfile):
            self._applyProfile = value
        @property
        def failures(self) -> List[vim.fault.ProfileUpdateFailed.UpdateFailure]: ...
        @failures.setter
        def failures(self, value: List[vim.fault.ProfileUpdateFailed.UpdateFailure]):
            self._failures = value
        @property
        def faults(self) -> List[vmodl.MethodFault]: ...
        @faults.setter
        def faults(self, value: List[vmodl.MethodFault]):
            self._faults = value


        class UpdateType(Enum):
            HostBased = "HostBased"
            Import = "Import"
            Edit = "Edit"
            Compose = "Compose"


    class ValidationState(Enum):
        Ready = "Ready"
        Running = "Running"
        Failed = "Failed"


class HostSpecificationManager(ManagedObject):
    def UpdateHostSpecification(self, host: vim.HostSystem, hostSpec: HostSpecification) -> NoneType: ...
    def UpdateHostSubSpecification(self, host: vim.HostSystem, hostSubSpec: HostSubSpecification) -> NoneType: ...
    def RetrieveHostSpecification(self, host: vim.HostSystem, fromHost: bool) -> HostSpecification: ...
    def DeleteHostSubSpecification(self, host: vim.HostSystem, subSpecName: str) -> NoneType: ...
    def DeleteHostSpecification(self, host: vim.HostSystem) -> NoneType: ...
    def GetUpdatedHosts(self, startChangeID: str, endChangeID: str) -> List[vim.HostSystem]: ...


class ProfileManager(vim.profile.ProfileManager):
    def ApplyHostConfiguration(self, host: vim.HostSystem, configSpec: vim.host.ConfigSpec, userInput: List[vim.profile.DeferredPolicyOptionParameter]) -> vim.Task: ...
    def GenerateConfigTaskList(self, configSpec: vim.host.ConfigSpec, host: vim.HostSystem) -> ProfileManager.ConfigTaskList: ...
    def GenerateTaskList(self, configSpec: vim.host.ConfigSpec, host: vim.HostSystem) -> vim.Task: ...
    def QueryProfileMetadata(self, profileName: List[type], profile: vim.profile.Profile) -> List[vim.profile.ProfileMetadata]: ...
    def QueryProfileStructure(self, profile: vim.profile.Profile) -> vim.profile.ProfileStructure: ...
    def CreateDefaultProfile(self, profileType: type, profileTypeName: str, profile: vim.profile.Profile) -> vim.profile.ApplyProfile: ...
    def UpdateAnswerFile(self, host: vim.HostSystem, configSpec: ProfileManager.AnswerFileCreateSpec) -> vim.Task: ...
    def RetrieveAnswerFile(self, host: vim.HostSystem) -> AnswerFile: ...
    def RetrieveAnswerFileForProfile(self, host: vim.HostSystem, applyProfile: HostApplyProfile) -> AnswerFile: ...
    def ExportAnswerFile(self, host: vim.HostSystem) -> vim.Task: ...
    def CheckAnswerFileStatus(self, host: List[vim.HostSystem]) -> vim.Task: ...
    def QueryAnswerFileStatus(self, host: List[vim.HostSystem]) -> List[AnswerFileStatusResult]: ...
    def RetrieveHostCustomizations(self, hosts: List[vim.HostSystem]) -> List[ProfileManager.StructuredCustomizations]: ...
    def RetrieveHostCustomizationsForProfile(self, hosts: List[vim.HostSystem], applyProfile: HostApplyProfile) -> List[ProfileManager.StructuredCustomizations]: ...
    def GenerateHostConfigTaskSpec(self, hostsInfo: List[ProfileManager.StructuredCustomizations]) -> vim.Task: ...
    def ApplyEntitiesConfiguration(self, applyConfigSpecs: List[ProfileManager.ApplyHostConfigSpec]) -> vim.Task: ...
    def ValidateComposition(self, source: vim.profile.Profile, targets: List[vim.profile.Profile], toBeMerged: HostApplyProfile, toReplaceWith: HostApplyProfile, toBeDeleted: HostApplyProfile, enableStatusToBeCopied: HostApplyProfile, errorOnly: bool) -> vim.Task: ...
    def CompositeProfile(self, source: vim.profile.Profile, targets: List[vim.profile.Profile], toBeMerged: HostApplyProfile, toBeReplacedWith: HostApplyProfile, toBeDeleted: HostApplyProfile, enableStatusToBeCopied: HostApplyProfile) -> vim.Task: ...


    class AnswerFileCreateSpec(vmodl.DynamicData):
        @property
        def validating(self) -> bool: ...
        @validating.setter
        def validating(self, value: bool):
            self._validating = value


    class AnswerFileOptionsCreateSpec(ProfileManager.AnswerFileCreateSpec):
        @property
        def userInput(self) -> List[vim.profile.DeferredPolicyOptionParameter]: ...
        @userInput.setter
        def userInput(self, value: List[vim.profile.DeferredPolicyOptionParameter]):
            self._userInput = value


    class AnswerFileSerializedCreateSpec(ProfileManager.AnswerFileCreateSpec):
        @property
        def answerFileConfigString(self) -> str: ...
        @answerFileConfigString.setter
        def answerFileConfigString(self, value: str):
            self._answerFileConfigString = value


    class ApplyHostConfigResult(vmodl.DynamicData):
        @property
        def startTime(self) -> datetime: ...
        @startTime.setter
        def startTime(self, value: datetime):
            self._startTime = value
        @property
        def completeTime(self) -> datetime: ...
        @completeTime.setter
        def completeTime(self, value: datetime):
            self._completeTime = value
        @property
        def host(self) -> vim.HostSystem: ...
        @host.setter
        def host(self, value: vim.HostSystem):
            self._host = value
        @property
        def status(self) -> str: ...
        @status.setter
        def status(self, value: str):
            self._status = value
        @property
        def errors(self) -> List[vmodl.MethodFault]: ...
        @errors.setter
        def errors(self, value: List[vmodl.MethodFault]):
            self._errors = value


    class ApplyHostConfigSpec(ExecuteResult):
        @property
        def host(self) -> vim.HostSystem: ...
        @host.setter
        def host(self, value: vim.HostSystem):
            self._host = value
        @property
        def taskListRequirement(self) -> List[str]: ...
        @taskListRequirement.setter
        def taskListRequirement(self, value: List[str]):
            self._taskListRequirement = value
        @property
        def taskDescription(self) -> List[vmodl.LocalizableMessage]: ...
        @taskDescription.setter
        def taskDescription(self, value: List[vmodl.LocalizableMessage]):
            self._taskDescription = value
        @property
        def rebootStateless(self) -> bool: ...
        @rebootStateless.setter
        def rebootStateless(self, value: bool):
            self._rebootStateless = value
        @property
        def rebootHost(self) -> bool: ...
        @rebootHost.setter
        def rebootHost(self, value: bool):
            self._rebootHost = value
        @property
        def faultData(self) -> vmodl.MethodFault: ...
        @faultData.setter
        def faultData(self, value: vmodl.MethodFault):
            self._faultData = value


    class CompositionResult(vmodl.DynamicData):
        @property
        def errors(self) -> List[vmodl.LocalizableMessage]: ...
        @errors.setter
        def errors(self, value: List[vmodl.LocalizableMessage]):
            self._errors = value
        @property
        def results(self) -> List[ProfileManager.CompositionResult.ResultElement]: ...
        @results.setter
        def results(self, value: List[ProfileManager.CompositionResult.ResultElement]):
            self._results = value


        class ResultElement(vmodl.DynamicData):
            @property
            def target(self) -> vim.profile.Profile: ...
            @target.setter
            def target(self, value: vim.profile.Profile):
                self._target = value
            @property
            def status(self) -> str: ...
            @status.setter
            def status(self, value: str):
                self._status = value
            @property
            def errors(self) -> List[vmodl.LocalizableMessage]: ...
            @errors.setter
            def errors(self, value: List[vmodl.LocalizableMessage]):
                self._errors = value


    class CompositionValidationResult(vmodl.DynamicData):
        @property
        def results(self) -> List[ProfileManager.CompositionValidationResult.ResultElement]: ...
        @results.setter
        def results(self, value: List[ProfileManager.CompositionValidationResult.ResultElement]):
            self._results = value
        @property
        def errors(self) -> List[vmodl.LocalizableMessage]: ...
        @errors.setter
        def errors(self, value: List[vmodl.LocalizableMessage]):
            self._errors = value


        class ResultElement(vmodl.DynamicData):
            @property
            def target(self) -> vim.profile.Profile: ...
            @target.setter
            def target(self, value: vim.profile.Profile):
                self._target = value
            @property
            def status(self) -> str: ...
            @status.setter
            def status(self, value: str):
                self._status = value
            @property
            def errors(self) -> List[vmodl.LocalizableMessage]: ...
            @errors.setter
            def errors(self, value: List[vmodl.LocalizableMessage]):
                self._errors = value
            @property
            def sourceDiffForToBeMerged(self) -> HostApplyProfile: ...
            @sourceDiffForToBeMerged.setter
            def sourceDiffForToBeMerged(self, value: HostApplyProfile):
                self._sourceDiffForToBeMerged = value
            @property
            def targetDiffForToBeMerged(self) -> HostApplyProfile: ...
            @targetDiffForToBeMerged.setter
            def targetDiffForToBeMerged(self, value: HostApplyProfile):
                self._targetDiffForToBeMerged = value
            @property
            def toBeAdded(self) -> HostApplyProfile: ...
            @toBeAdded.setter
            def toBeAdded(self, value: HostApplyProfile):
                self._toBeAdded = value
            @property
            def toBeDeleted(self) -> HostApplyProfile: ...
            @toBeDeleted.setter
            def toBeDeleted(self, value: HostApplyProfile):
                self._toBeDeleted = value
            @property
            def toBeDisabled(self) -> HostApplyProfile: ...
            @toBeDisabled.setter
            def toBeDisabled(self, value: HostApplyProfile):
                self._toBeDisabled = value
            @property
            def toBeEnabled(self) -> HostApplyProfile: ...
            @toBeEnabled.setter
            def toBeEnabled(self, value: HostApplyProfile):
                self._toBeEnabled = value
            @property
            def toBeReenableCC(self) -> HostApplyProfile: ...
            @toBeReenableCC.setter
            def toBeReenableCC(self, value: HostApplyProfile):
                self._toBeReenableCC = value


    class ConfigTaskList(vmodl.DynamicData):
        @property
        def configSpec(self) -> vim.host.ConfigSpec: ...
        @configSpec.setter
        def configSpec(self, value: vim.host.ConfigSpec):
            self._configSpec = value
        @property
        def taskDescription(self) -> List[vmodl.LocalizableMessage]: ...
        @taskDescription.setter
        def taskDescription(self, value: List[vmodl.LocalizableMessage]):
            self._taskDescription = value
        @property
        def taskListRequirement(self) -> List[str]: ...
        @taskListRequirement.setter
        def taskListRequirement(self, value: List[str]):
            self._taskListRequirement = value


    class EntityCustomizations(vmodl.DynamicData): ...


    class HostToConfigSpecMap(vmodl.DynamicData):
        @property
        def host(self) -> vim.HostSystem: ...
        @host.setter
        def host(self, value: vim.HostSystem):
            self._host = value
        @property
        def configSpec(self) -> ProfileManager.AnswerFileCreateSpec: ...
        @configSpec.setter
        def configSpec(self, value: ProfileManager.AnswerFileCreateSpec):
            self._configSpec = value


    class StructuredCustomizations(ProfileManager.EntityCustomizations):
        @property
        def entity(self) -> vim.ManagedEntity: ...
        @entity.setter
        def entity(self, value: vim.ManagedEntity):
            self._entity = value
        @property
        def customizations(self) -> AnswerFile: ...
        @customizations.setter
        def customizations(self, value: AnswerFile):
            self._customizations = value


    class AnswerFileStatus(Enum):
        valid = "valid"
        invalid = "invalid"
        unknown = "unknown"


    class TaskListRequirement(Enum):
        maintenanceModeRequired = "maintenanceModeRequired"
        rebootRequired = "rebootRequired"


class ActiveDirectoryProfile(vim.profile.ApplyProfile): ...


class AnswerFile(vmodl.DynamicData):
    @property
    def userInput(self) -> List[vim.profile.DeferredPolicyOptionParameter]: ...
    @userInput.setter
    def userInput(self, value: List[vim.profile.DeferredPolicyOptionParameter]):
        self._userInput = value
    @property
    def createdTime(self) -> datetime: ...
    @createdTime.setter
    def createdTime(self, value: datetime):
        self._createdTime = value
    @property
    def modifiedTime(self) -> datetime: ...
    @modifiedTime.setter
    def modifiedTime(self, value: datetime):
        self._modifiedTime = value


class AnswerFileStatusResult(vmodl.DynamicData):
    @property
    def checkedTime(self) -> datetime: ...
    @checkedTime.setter
    def checkedTime(self, value: datetime):
        self._checkedTime = value
    @property
    def host(self) -> vim.HostSystem: ...
    @host.setter
    def host(self, value: vim.HostSystem):
        self._host = value
    @property
    def status(self) -> str: ...
    @status.setter
    def status(self, value: str):
        self._status = value
    @property
    def error(self) -> List[AnswerFileStatusResult.AnswerFileStatusError]: ...
    @error.setter
    def error(self, value: List[AnswerFileStatusResult.AnswerFileStatusError]):
        self._error = value


    class AnswerFileStatusError(vmodl.DynamicData):
        @property
        def userInputPath(self) -> vim.profile.ProfilePropertyPath: ...
        @userInputPath.setter
        def userInputPath(self, value: vim.profile.ProfilePropertyPath):
            self._userInputPath = value
        @property
        def errMsg(self) -> vmodl.LocalizableMessage: ...
        @errMsg.setter
        def errMsg(self, value: vmodl.LocalizableMessage):
            self._errMsg = value


class AuthenticationProfile(vim.profile.ApplyProfile):
    @property
    def activeDirectory(self) -> ActiveDirectoryProfile: ...
    @activeDirectory.setter
    def activeDirectory(self, value: ActiveDirectoryProfile):
        self._activeDirectory = value


class DateTimeProfile(vim.profile.ApplyProfile): ...


class DvsHostVNicProfile(DvsVNicProfile): ...


class DvsProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def uplink(self) -> List[PnicUplinkProfile]: ...
    @uplink.setter
    def uplink(self, value: List[PnicUplinkProfile]):
        self._uplink = value


class DvsServiceConsoleVNicProfile(DvsVNicProfile): ...


class DvsVNicProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def ipConfig(self) -> IpAddressProfile: ...
    @ipConfig.setter
    def ipConfig(self, value: IpAddressProfile):
        self._ipConfig = value


class ExecuteResult(vmodl.DynamicData):
    @property
    def status(self) -> str: ...
    @status.setter
    def status(self, value: str):
        self._status = value
    @property
    def configSpec(self) -> vim.host.ConfigSpec: ...
    @configSpec.setter
    def configSpec(self, value: vim.host.ConfigSpec):
        self._configSpec = value
    @property
    def inapplicablePath(self) -> List[PropertyPath]: ...
    @inapplicablePath.setter
    def inapplicablePath(self, value: List[PropertyPath]):
        self._inapplicablePath = value
    @property
    def requireInput(self) -> List[vim.profile.DeferredPolicyOptionParameter]: ...
    @requireInput.setter
    def requireInput(self, value: List[vim.profile.DeferredPolicyOptionParameter]):
        self._requireInput = value
    @property
    def error(self) -> List[ExecuteResult.ExecuteError]: ...
    @error.setter
    def error(self, value: List[ExecuteResult.ExecuteError]):
        self._error = value


    class ExecuteError(vmodl.DynamicData):
        @property
        def path(self) -> vim.profile.ProfilePropertyPath: ...
        @path.setter
        def path(self, value: vim.profile.ProfilePropertyPath):
            self._path = value
        @property
        def message(self) -> vmodl.LocalizableMessage: ...
        @message.setter
        def message(self, value: vmodl.LocalizableMessage):
            self._message = value


    class Status(Enum):
        success = "success"
        needInput = "needInput"
        error = "error"


class FirewallProfile(vim.profile.ApplyProfile):
    @property
    def ruleset(self) -> List[FirewallProfile.RulesetProfile]: ...
    @ruleset.setter
    def ruleset(self, value: List[FirewallProfile.RulesetProfile]):
        self._ruleset = value


    class RulesetProfile(vim.profile.ApplyProfile):
        @property
        def key(self) -> str: ...
        @key.setter
        def key(self, value: str):
            self._key = value


class HostApplyProfile(vim.profile.ApplyProfile):
    @property
    def memory(self) -> HostMemoryProfile: ...
    @memory.setter
    def memory(self, value: HostMemoryProfile):
        self._memory = value
    @property
    def storage(self) -> StorageProfile: ...
    @storage.setter
    def storage(self, value: StorageProfile):
        self._storage = value
    @property
    def network(self) -> NetworkProfile: ...
    @network.setter
    def network(self, value: NetworkProfile):
        self._network = value
    @property
    def datetime(self) -> DateTimeProfile: ...
    @datetime.setter
    def datetime(self, value: DateTimeProfile):
        self._datetime = value
    @property
    def firewall(self) -> FirewallProfile: ...
    @firewall.setter
    def firewall(self, value: FirewallProfile):
        self._firewall = value
    @property
    def security(self) -> SecurityProfile: ...
    @security.setter
    def security(self, value: SecurityProfile):
        self._security = value
    @property
    def service(self) -> List[ServiceProfile]: ...
    @service.setter
    def service(self, value: List[ServiceProfile]):
        self._service = value
    @property
    def option(self) -> List[OptionProfile]: ...
    @option.setter
    def option(self, value: List[OptionProfile]):
        self._option = value
    @property
    def userAccount(self) -> List[UserProfile]: ...
    @userAccount.setter
    def userAccount(self, value: List[UserProfile]):
        self._userAccount = value
    @property
    def usergroupAccount(self) -> List[UserGroupProfile]: ...
    @usergroupAccount.setter
    def usergroupAccount(self, value: List[UserGroupProfile]):
        self._usergroupAccount = value
    @property
    def authentication(self) -> AuthenticationProfile: ...
    @authentication.setter
    def authentication(self, value: AuthenticationProfile):
        self._authentication = value


class HostMemoryProfile(vim.profile.ApplyProfile): ...


class HostPortGroupProfile(PortGroupProfile):
    @property
    def ipConfig(self) -> IpAddressProfile: ...
    @ipConfig.setter
    def ipConfig(self, value: IpAddressProfile):
        self._ipConfig = value


class HostSpecification(vmodl.DynamicData):
    @property
    def createdTime(self) -> datetime: ...
    @createdTime.setter
    def createdTime(self, value: datetime):
        self._createdTime = value
    @property
    def lastModified(self) -> datetime: ...
    @lastModified.setter
    def lastModified(self, value: datetime):
        self._lastModified = value
    @property
    def host(self) -> vim.HostSystem: ...
    @host.setter
    def host(self, value: vim.HostSystem):
        self._host = value
    @property
    def subSpecs(self) -> List[HostSubSpecification]: ...
    @subSpecs.setter
    def subSpecs(self, value: List[HostSubSpecification]):
        self._subSpecs = value
    @property
    def changeID(self) -> str: ...
    @changeID.setter
    def changeID(self, value: str):
        self._changeID = value


class HostSubSpecification(vmodl.DynamicData):
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def createdTime(self) -> datetime: ...
    @createdTime.setter
    def createdTime(self, value: datetime):
        self._createdTime = value
    @property
    def data(self) -> List[byte]: ...
    @data.setter
    def data(self, value: List[byte]):
        self._data = value
    @property
    def binaryData(self) -> binary: ...
    @binaryData.setter
    def binaryData(self, value: binary):
        self._binaryData = value


class IpAddressProfile(vim.profile.ApplyProfile): ...


class IpRouteProfile(vim.profile.ApplyProfile):
    @property
    def staticRoute(self) -> List[StaticRouteProfile]: ...
    @staticRoute.setter
    def staticRoute(self, value: List[StaticRouteProfile]):
        self._staticRoute = value


class NasStorageProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class NetStackInstanceProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def dnsConfig(self) -> NetworkProfile.DnsConfigProfile: ...
    @dnsConfig.setter
    def dnsConfig(self, value: NetworkProfile.DnsConfigProfile):
        self._dnsConfig = value
    @property
    def ipRouteConfig(self) -> IpRouteProfile: ...
    @ipRouteConfig.setter
    def ipRouteConfig(self, value: IpRouteProfile):
        self._ipRouteConfig = value


class NetworkPolicyProfile(vim.profile.ApplyProfile): ...


class NetworkProfile(vim.profile.ApplyProfile):
    @property
    def vswitch(self) -> List[VirtualSwitchProfile]: ...
    @vswitch.setter
    def vswitch(self, value: List[VirtualSwitchProfile]):
        self._vswitch = value
    @property
    def vmPortGroup(self) -> List[VmPortGroupProfile]: ...
    @vmPortGroup.setter
    def vmPortGroup(self, value: List[VmPortGroupProfile]):
        self._vmPortGroup = value
    @property
    def hostPortGroup(self) -> List[HostPortGroupProfile]: ...
    @hostPortGroup.setter
    def hostPortGroup(self, value: List[HostPortGroupProfile]):
        self._hostPortGroup = value
    @property
    def serviceConsolePortGroup(self) -> List[ServiceConsolePortGroupProfile]: ...
    @serviceConsolePortGroup.setter
    def serviceConsolePortGroup(self, value: List[ServiceConsolePortGroupProfile]):
        self._serviceConsolePortGroup = value
    @property
    def dnsConfig(self) -> NetworkProfile.DnsConfigProfile: ...
    @dnsConfig.setter
    def dnsConfig(self, value: NetworkProfile.DnsConfigProfile):
        self._dnsConfig = value
    @property
    def ipRouteConfig(self) -> IpRouteProfile: ...
    @ipRouteConfig.setter
    def ipRouteConfig(self, value: IpRouteProfile):
        self._ipRouteConfig = value
    @property
    def consoleIpRouteConfig(self) -> IpRouteProfile: ...
    @consoleIpRouteConfig.setter
    def consoleIpRouteConfig(self, value: IpRouteProfile):
        self._consoleIpRouteConfig = value
    @property
    def pnic(self) -> List[PhysicalNicProfile]: ...
    @pnic.setter
    def pnic(self, value: List[PhysicalNicProfile]):
        self._pnic = value
    @property
    def dvswitch(self) -> List[DvsProfile]: ...
    @dvswitch.setter
    def dvswitch(self, value: List[DvsProfile]):
        self._dvswitch = value
    @property
    def dvsServiceConsoleNic(self) -> List[DvsServiceConsoleVNicProfile]: ...
    @dvsServiceConsoleNic.setter
    def dvsServiceConsoleNic(self, value: List[DvsServiceConsoleVNicProfile]):
        self._dvsServiceConsoleNic = value
    @property
    def dvsHostNic(self) -> List[DvsHostVNicProfile]: ...
    @dvsHostNic.setter
    def dvsHostNic(self, value: List[DvsHostVNicProfile]):
        self._dvsHostNic = value
    @property
    def nsxHostNic(self) -> List[NsxHostVNicProfile]: ...
    @nsxHostNic.setter
    def nsxHostNic(self, value: List[NsxHostVNicProfile]):
        self._nsxHostNic = value
    @property
    def netStackInstance(self) -> List[NetStackInstanceProfile]: ...
    @netStackInstance.setter
    def netStackInstance(self, value: List[NetStackInstanceProfile]):
        self._netStackInstance = value
    @property
    def opaqueSwitch(self) -> OpaqueSwitchProfile: ...
    @opaqueSwitch.setter
    def opaqueSwitch(self, value: OpaqueSwitchProfile):
        self._opaqueSwitch = value


    class DnsConfigProfile(vim.profile.ApplyProfile): ...


class NsxHostVNicProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def ipConfig(self) -> IpAddressProfile: ...
    @ipConfig.setter
    def ipConfig(self, value: IpAddressProfile):
        self._ipConfig = value


class OpaqueSwitchProfile(vim.profile.ApplyProfile): ...


class OptionProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class PermissionProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class PhysicalNicProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class PnicUplinkProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class PortGroupProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def vlan(self) -> PortGroupProfile.VlanProfile: ...
    @vlan.setter
    def vlan(self, value: PortGroupProfile.VlanProfile):
        self._vlan = value
    @property
    def vswitch(self) -> PortGroupProfile.VirtualSwitchSelectionProfile: ...
    @vswitch.setter
    def vswitch(self, value: PortGroupProfile.VirtualSwitchSelectionProfile):
        self._vswitch = value
    @property
    def networkPolicy(self) -> NetworkPolicyProfile: ...
    @networkPolicy.setter
    def networkPolicy(self, value: NetworkPolicyProfile):
        self._networkPolicy = value


    class VirtualSwitchSelectionProfile(vim.profile.ApplyProfile): ...


    class VlanProfile(vim.profile.ApplyProfile): ...


class SecurityProfile(vim.profile.ApplyProfile):
    @property
    def permission(self) -> List[PermissionProfile]: ...
    @permission.setter
    def permission(self, value: List[PermissionProfile]):
        self._permission = value


class ServiceConsolePortGroupProfile(PortGroupProfile):
    @property
    def ipConfig(self) -> IpAddressProfile: ...
    @ipConfig.setter
    def ipConfig(self, value: IpAddressProfile):
        self._ipConfig = value


class ServiceProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class StaticRouteProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class StorageProfile(vim.profile.ApplyProfile):
    @property
    def nasStorage(self) -> List[NasStorageProfile]: ...
    @nasStorage.setter
    def nasStorage(self, value: List[NasStorageProfile]):
        self._nasStorage = value


class UserGroupProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class UserProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value


class VirtualSwitchProfile(vim.profile.ApplyProfile):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def link(self) -> VirtualSwitchProfile.LinkProfile: ...
    @link.setter
    def link(self, value: VirtualSwitchProfile.LinkProfile):
        self._link = value
    @property
    def numPorts(self) -> VirtualSwitchProfile.NumPortsProfile: ...
    @numPorts.setter
    def numPorts(self, value: VirtualSwitchProfile.NumPortsProfile):
        self._numPorts = value
    @property
    def networkPolicy(self) -> NetworkPolicyProfile: ...
    @networkPolicy.setter
    def networkPolicy(self, value: NetworkPolicyProfile):
        self._networkPolicy = value


    class LinkProfile(vim.profile.ApplyProfile): ...


    class NumPortsProfile(vim.profile.ApplyProfile): ...


class VmPortGroupProfile(PortGroupProfile): ...


from typing import List, Literal
from enum import Enum
from pyVmomi import vmodl
from pyVmomi.VmomiSupport import ManagedObject, NoneType, PropertyPath


class PropertyCollector(ManagedObject):
    @property
    def filter(self) -> List[PropertyCollector.Filter]: ...
    def CreateFilter(self, spec: PropertyCollector.FilterSpec, partialUpdates: bool) -> PropertyCollector.Filter: ...
    def RetrieveContents(self, specSet: List[PropertyCollector.FilterSpec]) -> List[PropertyCollector.ObjectContent]: ...
    def CheckForUpdates(self, version: str) -> PropertyCollector.UpdateSet: ...
    def WaitForUpdates(self, version: str) -> PropertyCollector.UpdateSet: ...
    def CancelWaitForUpdates(self) -> NoneType: ...
    def WaitForUpdatesEx(self, version: str, options: PropertyCollector.WaitOptions) -> PropertyCollector.UpdateSet: ...
    def RetrievePropertiesEx(self, specSet: List[PropertyCollector.FilterSpec], options: PropertyCollector.RetrieveOptions) -> PropertyCollector.RetrieveResult: ...
    def ContinueRetrievePropertiesEx(self, token: str) -> PropertyCollector.RetrieveResult: ...
    def CancelRetrievePropertiesEx(self, token: str) -> NoneType: ...
    def CreatePropertyCollector(self) -> PropertyCollector: ...
    def Destroy(self) -> NoneType: ...


    class Filter(ManagedObject):
        @property
        def spec(self) -> PropertyCollector.FilterSpec: ...
        @property
        def partialUpdates(self) -> bool: ...
        def Destroy(self) -> NoneType: ...


    class Change(vmodl.DynamicData):
        @property
        def name(self) -> PropertyPath: ...
        @name.setter
        def name(self, value: PropertyPath):
            self._name = value
        @property
        def op(self) -> PropertyCollector.Change.Op | Literal['add', 'remove', 'assign', 'indirectRemove']: ...
        @op.setter
        def op(self, value: PropertyCollector.Change.Op | Literal['add', 'remove', 'assign', 'indirectRemove']):
            self._op = value
        @property
        def val(self) -> object: ...
        @val.setter
        def val(self, value: object):
            self._val = value


        class Op(Enum):
            add = "add"
            remove = "remove"
            assign = "assign"
            indirectRemove = "indirectRemove"


    class FilterSpec(vmodl.DynamicData):
        @property
        def propSet(self) -> List[PropertyCollector.PropertySpec]: ...
        @propSet.setter
        def propSet(self, value: List[PropertyCollector.PropertySpec]):
            self._propSet = value
        @property
        def objectSet(self) -> List[PropertyCollector.ObjectSpec]: ...
        @objectSet.setter
        def objectSet(self, value: List[PropertyCollector.ObjectSpec]):
            self._objectSet = value
        @property
        def reportMissingObjectsInResults(self) -> bool: ...
        @reportMissingObjectsInResults.setter
        def reportMissingObjectsInResults(self, value: bool):
            self._reportMissingObjectsInResults = value


    class FilterUpdate(vmodl.DynamicData):
        @property
        def filter(self) -> PropertyCollector.Filter: ...
        @filter.setter
        def filter(self, value: PropertyCollector.Filter):
            self._filter = value
        @property
        def objectSet(self) -> List[PropertyCollector.ObjectUpdate]: ...
        @objectSet.setter
        def objectSet(self, value: List[PropertyCollector.ObjectUpdate]):
            self._objectSet = value
        @property
        def missingSet(self) -> List[PropertyCollector.MissingObject]: ...
        @missingSet.setter
        def missingSet(self, value: List[PropertyCollector.MissingObject]):
            self._missingSet = value


    class MissingObject(vmodl.DynamicData):
        @property
        def obj(self) -> ManagedObject: ...
        @obj.setter
        def obj(self, value: ManagedObject):
            self._obj = value
        @property
        def fault(self) -> vmodl.MethodFault: ...
        @fault.setter
        def fault(self, value: vmodl.MethodFault):
            self._fault = value


    class MissingProperty(vmodl.DynamicData):
        @property
        def path(self) -> PropertyPath: ...
        @path.setter
        def path(self, value: PropertyPath):
            self._path = value
        @property
        def fault(self) -> vmodl.MethodFault: ...
        @fault.setter
        def fault(self, value: vmodl.MethodFault):
            self._fault = value


    class ObjectContent(vmodl.DynamicData):
        @property
        def obj(self) -> ManagedObject: ...
        @obj.setter
        def obj(self, value: ManagedObject):
            self._obj = value
        @property
        def propSet(self) -> List[vmodl.DynamicProperty]: ...
        @propSet.setter
        def propSet(self, value: List[vmodl.DynamicProperty]):
            self._propSet = value
        @property
        def missingSet(self) -> List[PropertyCollector.MissingProperty]: ...
        @missingSet.setter
        def missingSet(self, value: List[PropertyCollector.MissingProperty]):
            self._missingSet = value


    class ObjectSpec(vmodl.DynamicData):
        @property
        def obj(self) -> ManagedObject: ...
        @obj.setter
        def obj(self, value: ManagedObject):
            self._obj = value
        @property
        def skip(self) -> bool: ...
        @skip.setter
        def skip(self, value: bool):
            self._skip = value
        @property
        def selectSet(self) -> List[PropertyCollector.SelectionSpec]: ...
        @selectSet.setter
        def selectSet(self, value: List[PropertyCollector.SelectionSpec]):
            self._selectSet = value


    class ObjectUpdate(vmodl.DynamicData):
        @property
        def kind(self) -> PropertyCollector.ObjectUpdate.Kind | Literal['modify', 'enter', 'leave']: ...
        @kind.setter
        def kind(self, value: PropertyCollector.ObjectUpdate.Kind | Literal['modify', 'enter', 'leave']):
            self._kind = value
        @property
        def obj(self) -> ManagedObject: ...
        @obj.setter
        def obj(self, value: ManagedObject):
            self._obj = value
        @property
        def changeSet(self) -> List[PropertyCollector.Change]: ...
        @changeSet.setter
        def changeSet(self, value: List[PropertyCollector.Change]):
            self._changeSet = value
        @property
        def missingSet(self) -> List[PropertyCollector.MissingProperty]: ...
        @missingSet.setter
        def missingSet(self, value: List[PropertyCollector.MissingProperty]):
            self._missingSet = value


        class Kind(Enum):
            modify = "modify"
            enter = "enter"
            leave = "leave"


    class PropertySpec(vmodl.DynamicData):
        @property
        def type(self) -> type: ...
        @type.setter
        def type(self, value: type):
            self._type = value
        @property
        def all(self) -> bool: ...
        @all.setter
        def all(self, value: bool):
            self._all = value
        @property
        def pathSet(self) -> List[PropertyPath]: ...
        @pathSet.setter
        def pathSet(self, value: List[PropertyPath]):
            self._pathSet = value


    class RetrieveOptions(vmodl.DynamicData):
        @property
        def maxObjects(self) -> int: ...
        @maxObjects.setter
        def maxObjects(self, value: int):
            self._maxObjects = value


    class RetrieveResult(vmodl.DynamicData):
        @property
        def token(self) -> str: ...
        @token.setter
        def token(self, value: str):
            self._token = value
        @property
        def objects(self) -> List[PropertyCollector.ObjectContent]: ...
        @objects.setter
        def objects(self, value: List[PropertyCollector.ObjectContent]):
            self._objects = value


    class SelectionSpec(vmodl.DynamicData):
        @property
        def name(self) -> str: ...
        @name.setter
        def name(self, value: str):
            self._name = value


    class TraversalSpec(PropertyCollector.SelectionSpec):
        @property
        def type(self) -> type: ...
        @type.setter
        def type(self, value: type):
            self._type = value
        @property
        def path(self) -> PropertyPath: ...
        @path.setter
        def path(self, value: PropertyPath):
            self._path = value
        @property
        def skip(self) -> bool: ...
        @skip.setter
        def skip(self, value: bool):
            self._skip = value
        @property
        def selectSet(self) -> List[PropertyCollector.SelectionSpec]: ...
        @selectSet.setter
        def selectSet(self, value: List[PropertyCollector.SelectionSpec]):
            self._selectSet = value


    class UpdateSet(vmodl.DynamicData):
        @property
        def version(self) -> str: ...
        @version.setter
        def version(self, value: str):
            self._version = value
        @property
        def filterSet(self) -> List[PropertyCollector.FilterUpdate]: ...
        @filterSet.setter
        def filterSet(self, value: List[PropertyCollector.FilterUpdate]):
            self._filterSet = value
        @property
        def truncated(self) -> bool: ...
        @truncated.setter
        def truncated(self, value: bool):
            self._truncated = value


    class WaitOptions(vmodl.DynamicData):
        @property
        def maxWaitSeconds(self) -> int: ...
        @maxWaitSeconds.setter
        def maxWaitSeconds(self, value: int):
            self._maxWaitSeconds = value
        @property
        def maxObjectUpdates(self) -> int: ...
        @maxObjectUpdates.setter
        def maxObjectUpdates(self, value: int):
            self._maxObjectUpdates = value


class InvalidCollectorVersion(vmodl.MethodFault): ...


class InvalidProperty(vmodl.MethodFault):
    @property
    def name(self) -> PropertyPath: ...
    @name.setter
    def name(self, value: PropertyPath):
        self._name = value


# **********************************************************
# Copyright (c) 2011-2023 VMware, Inc.
# **********************************************************

from .VmomiSupport import GetVmodlType, ManagedObject, Object


# Used to replace few type definitions for emulating
# legacy behavior. Ref. VmomiSupport._wsdlTypeMap
_legacyTypes = {
    "type": "string",
    "ManagedMethod": "string",
    "PropertyPath": "string",
    "type[]": "string[]",
    "ManagedMethod[]": "string[]",
    "PropertyPath[]": "string[]"
}


class StubAdapterAccessorMixin(object):

    # Retrieve a managed property
    #
    # @param self The object pointer
    # @param mo managed object
    # @param info property info
    def InvokeAccessor(self, mo, info):
        prop = info.name
        param = Object(name="prop", type=str, version=self.version, flags=0)

        # Emulate legacy behavior for backward compatibility
        replacement = _legacyTypes.get(info.type.__name__, None)
        if replacement:
            info.type = GetVmodlType(replacement)

        # When the type is a list of instances of ManagedObject
        # the legacy behavior was to return the base class
        # e.g. The returned object type was ManagedObject[] for
        # vim.Datastore[] or vim.ManagedEntity[]
        if info.type.__name__.endswith("[]"):
            elementTypeName = info.type.__name__[:-2]
            try:
                elementType = GetVmodlType(elementTypeName)
                if issubclass(elementType, ManagedObject):
                    info.type = GetVmodlType('vmodl.ManagedObject[]')
            except KeyError:
                pass

        info = Object(name=info.name,
                      type=ManagedObject,
                      wsdlName="Fetch",
                      version=info.version,
                      params=(param, ),
                      isTask=False,
                      resultFlags=info.flags,
                      result=info.type,
                      methodResult=info.type)
        return self.InvokeMethod(mo, info, (prop, ))

    def SupportServerGUIDs(self):
        return False



from typing import List
from pyVmomi import pbm, vim, vmodl
from pyVmomi.VmomiSupport import ManagedObject


class ReplicationManager(ManagedObject):
    def QueryReplicationGroups(self, entities: List[pbm.ServerObjectRef]) -> List[QueryReplicationGroupResult]: ...


class QueryReplicationGroupResult(vmodl.DynamicData):
    @property
    def object(self) -> pbm.ServerObjectRef: ...
    @object.setter
    def object(self, value: pbm.ServerObjectRef):
        self._object = value
    @property
    def replicationGroupId(self) -> vim.vm.replication.ReplicationGroupId: ...
    @replicationGroupId.setter
    def replicationGroupId(self, value: vim.vm.replication.ReplicationGroupId):
        self._replicationGroupId = value
    @property
    def fault(self) -> vmodl.MethodFault: ...
    @fault.setter
    def fault(self, value: vmodl.MethodFault):
        self._fault = value


from typing import List, Literal
from enum import Enum
from pyVmomi import vim, vmodl
from datetime import datetime
from pyVmomi.VmomiSupport import ManagedObject, NoneType


class ScheduledTask(vim.ExtensibleManagedObject):
    @property
    def info(self) -> ScheduledTaskInfo: ...
    def Remove(self) -> NoneType: ...
    def Reconfigure(self, spec: ScheduledTaskSpec) -> NoneType: ...
    def Run(self) -> NoneType: ...


class ScheduledTaskManager(ManagedObject):
    @property
    def scheduledTask(self) -> List[ScheduledTask]: ...
    @property
    def description(self) -> ScheduledTaskDescription: ...
    def Create(self, entity: vim.ManagedEntity, spec: ScheduledTaskSpec) -> ScheduledTask: ...
    def RetrieveEntityScheduledTask(self, entity: vim.ManagedEntity) -> List[ScheduledTask]: ...
    def CreateObjectScheduledTask(self, obj: ManagedObject, spec: ScheduledTaskSpec) -> ScheduledTask: ...
    def RetrieveObjectScheduledTask(self, obj: ManagedObject) -> List[ScheduledTask]: ...


class AfterStartupTaskScheduler(TaskScheduler):
    @property
    def minute(self) -> int: ...
    @minute.setter
    def minute(self, value: int):
        self._minute = value


class DailyTaskScheduler(HourlyTaskScheduler):
    @property
    def hour(self) -> int: ...
    @hour.setter
    def hour(self, value: int):
        self._hour = value


class HourlyTaskScheduler(RecurrentTaskScheduler):
    @property
    def minute(self) -> int: ...
    @minute.setter
    def minute(self, value: int):
        self._minute = value


class MonthlyByDayTaskScheduler(MonthlyTaskScheduler):
    @property
    def day(self) -> int: ...
    @day.setter
    def day(self, value: int):
        self._day = value


class MonthlyByWeekdayTaskScheduler(MonthlyTaskScheduler):
    @property
    def offset(self) -> MonthlyByWeekdayTaskScheduler.WeekOfMonth | Literal['first', 'second', 'third', 'fourth', 'last']: ...
    @offset.setter
    def offset(self, value: MonthlyByWeekdayTaskScheduler.WeekOfMonth | Literal['first', 'second', 'third', 'fourth', 'last']):
        self._offset = value
    @property
    def weekday(self) -> MonthlyByWeekdayTaskScheduler.DayOfWeek | Literal['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday']: ...
    @weekday.setter
    def weekday(self, value: MonthlyByWeekdayTaskScheduler.DayOfWeek | Literal['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday']):
        self._weekday = value


    class DayOfWeek(Enum):
        sunday = "sunday"
        monday = "monday"
        tuesday = "tuesday"
        wednesday = "wednesday"
        thursday = "thursday"
        friday = "friday"
        saturday = "saturday"


    class WeekOfMonth(Enum):
        first = "first"
        second = "second"
        third = "third"
        fourth = "fourth"
        last = "last"


class MonthlyTaskScheduler(DailyTaskScheduler): ...


class OnceTaskScheduler(TaskScheduler):
    @property
    def runAt(self) -> datetime: ...
    @runAt.setter
    def runAt(self, value: datetime):
        self._runAt = value


class RecurrentTaskScheduler(TaskScheduler):
    @property
    def interval(self) -> int: ...
    @interval.setter
    def interval(self, value: int):
        self._interval = value


class ScheduledTaskDescription(vmodl.DynamicData):
    @property
    def action(self) -> List[vim.TypeDescription]: ...
    @action.setter
    def action(self, value: List[vim.TypeDescription]):
        self._action = value
    @property
    def schedulerInfo(self) -> List[ScheduledTaskDescription.SchedulerDetail]: ...
    @schedulerInfo.setter
    def schedulerInfo(self, value: List[ScheduledTaskDescription.SchedulerDetail]):
        self._schedulerInfo = value
    @property
    def state(self) -> List[vim.ElementDescription]: ...
    @state.setter
    def state(self, value: List[vim.ElementDescription]):
        self._state = value
    @property
    def dayOfWeek(self) -> List[vim.ElementDescription]: ...
    @dayOfWeek.setter
    def dayOfWeek(self, value: List[vim.ElementDescription]):
        self._dayOfWeek = value
    @property
    def weekOfMonth(self) -> List[vim.ElementDescription]: ...
    @weekOfMonth.setter
    def weekOfMonth(self, value: List[vim.ElementDescription]):
        self._weekOfMonth = value


    class SchedulerDetail(vim.TypeDescription):
        @property
        def frequency(self) -> str: ...
        @frequency.setter
        def frequency(self, value: str):
            self._frequency = value


class ScheduledTaskInfo(ScheduledTaskSpec):
    @property
    def scheduledTask(self) -> ScheduledTask: ...
    @scheduledTask.setter
    def scheduledTask(self, value: ScheduledTask):
        self._scheduledTask = value
    @property
    def entity(self) -> vim.ManagedEntity: ...
    @entity.setter
    def entity(self, value: vim.ManagedEntity):
        self._entity = value
    @property
    def lastModifiedTime(self) -> datetime: ...
    @lastModifiedTime.setter
    def lastModifiedTime(self, value: datetime):
        self._lastModifiedTime = value
    @property
    def lastModifiedUser(self) -> str: ...
    @lastModifiedUser.setter
    def lastModifiedUser(self, value: str):
        self._lastModifiedUser = value
    @property
    def nextRunTime(self) -> datetime: ...
    @nextRunTime.setter
    def nextRunTime(self, value: datetime):
        self._nextRunTime = value
    @property
    def prevRunTime(self) -> datetime: ...
    @prevRunTime.setter
    def prevRunTime(self, value: datetime):
        self._prevRunTime = value
    @property
    def state(self) -> vim.TaskInfo.State | Literal['queued', 'running', 'success', 'error']: ...
    @state.setter
    def state(self, value: vim.TaskInfo.State | Literal['queued', 'running', 'success', 'error']):
        self._state = value
    @property
    def error(self) -> vmodl.MethodFault: ...
    @error.setter
    def error(self, value: vmodl.MethodFault):
        self._error = value
    @property
    def result(self) -> object: ...
    @result.setter
    def result(self, value: object):
        self._result = value
    @property
    def progress(self) -> int: ...
    @progress.setter
    def progress(self, value: int):
        self._progress = value
    @property
    def activeTask(self) -> vim.Task: ...
    @activeTask.setter
    def activeTask(self, value: vim.Task):
        self._activeTask = value
    @property
    def taskObject(self) -> ManagedObject: ...
    @taskObject.setter
    def taskObject(self, value: ManagedObject):
        self._taskObject = value


class ScheduledTaskSpec(vmodl.DynamicData):
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def description(self) -> str: ...
    @description.setter
    def description(self, value: str):
        self._description = value
    @property
    def enabled(self) -> bool: ...
    @enabled.setter
    def enabled(self, value: bool):
        self._enabled = value
    @property
    def scheduler(self) -> TaskScheduler: ...
    @scheduler.setter
    def scheduler(self, value: TaskScheduler):
        self._scheduler = value
    @property
    def action(self) -> vim.action.Action: ...
    @action.setter
    def action(self, value: vim.action.Action):
        self._action = value
    @property
    def notification(self) -> str: ...
    @notification.setter
    def notification(self, value: str):
        self._notification = value


class TaskScheduler(vmodl.DynamicData):
    @property
    def activeTime(self) -> datetime: ...
    @activeTime.setter
    def activeTime(self, value: datetime):
        self._activeTime = value
    @property
    def expireTime(self) -> datetime: ...
    @expireTime.setter
    def expireTime(self, value: datetime):
        self._expireTime = value


class WeeklyTaskScheduler(DailyTaskScheduler):
    @property
    def sunday(self) -> bool: ...
    @sunday.setter
    def sunday(self, value: bool):
        self._sunday = value
    @property
    def monday(self) -> bool: ...
    @monday.setter
    def monday(self, value: bool):
        self._monday = value
    @property
    def tuesday(self) -> bool: ...
    @tuesday.setter
    def tuesday(self, value: bool):
        self._tuesday = value
    @property
    def wednesday(self) -> bool: ...
    @wednesday.setter
    def wednesday(self, value: bool):
        self._wednesday = value
    @property
    def thursday(self) -> bool: ...
    @thursday.setter
    def thursday(self, value: bool):
        self._thursday = value
    @property
    def friday(self) -> bool: ...
    @friday.setter
    def friday(self, value: bool):
        self._friday = value
    @property
    def saturday(self) -> bool: ...
    @saturday.setter
    def saturday(self, value: bool):
        self._saturday = value